@@ -16,14 +16,13 @@
 __docformat__ = 'restructuredtext'
 
 import zope.component
-from zope.interface import implements, Invalid
+from zope.interface import implementer, Invalid
 from zope.exceptions import DuplicationError
-from zope.component import adapts
+from zope.component import adapter
 from zope.copy import copy
 from zope.event import notify
 from zope.location.interfaces import ISublocations
 from zope.annotation.interfaces import IAnnotations
-from zope.annotation.interfaces import IAnnotations
 from zope.lifecycleevent import ObjectCopiedEvent
 
 from zope.copypastemove.interfaces import IObjectMover
@@ -34,10 +33,13 @@ from zope.copypastemove.interfaces import ItemNotFoundError
 
 from zope.container.sample import SampleContainer
 from zope.container.interfaces import IContainer, IOrderedContainer
-from zope.container.interfaces import IContained
+from zope.location.interfaces import IContained
 from zope.container.interfaces import INameChooser
 from zope.container.constraints import checkObject
 
+
+@adapter(IContained)
+@implementer(IObjectMover)
 class ObjectMover(object):
     """Adapter for moving objects between containers
 
@@ -130,12 +132,11 @@ class ObjectMover(object):
     ...     __setitem__.precondition = preNoZ
 
     >>> from zope.container.interfaces import IContainer
-    >>> class C1(object):
-    ...     zope.interface.implements(I1, IContainer)
+    >>> @zope.interface.implementer(I1, IContainer)
+    ... class C1(object):
     ...     def __repr__(self):
     ...         return 'C1'
 
-    >>> from zope.container.constraints import checkObject
     >>> container3 = C1()
     >>> mover.moveableTo(container3, 'ZDummy')
     False
@@ -153,8 +154,8 @@ class ObjectMover(object):
     >>> class I2(zope.interface.Interface):
     ...     __parent__ = zope.schema.Field(constraint=con1)
     ...
-    >>> class constrainedObject(object):
-    ...     zope.interface.implements(I2)
+    >>> @zope.interface.implementer(I2)
+    ... class constrainedObject(object):
     ...     def __init__(self):
     ...         self.__name__ = 'constrainedObject'
     ...
@@ -168,13 +169,9 @@ class ObjectMover(object):
 
     """
 
-    adapts(IContained)
-
-    implements(IObjectMover)
-
     def __init__(self, object):
         self.context = object
-        self.__parent__ = object # TODO: see if we can automate this
+        self.__parent__ = object  # TODO: see if we can automate this
 
     def moveTo(self, target, new_name=None):
         """Move this object to the `target` given.
@@ -224,6 +221,9 @@ class ObjectMover(object):
             return False
         return True
 
+
+@adapter(IContained)
+@implementer(IObjectCopier)
 class ObjectCopier(object):
     """Adapter for copying objects between containers
 
@@ -326,12 +326,11 @@ class ObjectCopier(object):
     ...     __setitem__.precondition = preNoZ
 
     >>> from zope.container.interfaces import IContainer
-    >>> class C1(object):
-    ...     zope.interface.implements(I1, IContainer)
+    >>> @zope.interface.implementer(I1, IContainer)
+    ... class C1(object):
     ...     def __repr__(self):
     ...         return 'C1'
 
-    >>> from zope.container.constraints import checkObject
     >>> container3 = C1()
     >>> copier.copyableTo(container3, 'ZDummy')
     False
@@ -349,8 +348,8 @@ class ObjectCopier(object):
     >>> class I2(zope.interface.Interface):
     ...     __parent__ = zope.schema.Field(constraint=con1)
     ...
-    >>> class constrainedObject(object):
-    ...     zope.interface.implements(I2)
+    >>> @zope.interface.implementer(I2)
+    ... class constrainedObject(object):
     ...     def __init__(self):
     ...         self.__name__ = 'constrainedObject'
     ...
@@ -364,13 +363,9 @@ class ObjectCopier(object):
 
     """
 
-    adapts(IContained)
-
-    implements(IObjectCopier)
-
     def __init__(self, object):
         self.context = object
-        self.__parent__ = object # TODO: see if we can automate this
+        self.__parent__ = object  # TODO: see if we can automate this
 
     def copyTo(self, target, new_name=None):
         """Copy this object to the `target` given.
@@ -380,7 +375,6 @@ class ObjectCopier(object):
         an `IObjectCopied` event is published.
         """
         obj = self.context
-        container = obj.__parent__
 
         orig_name = obj.__name__
         if new_name is None:
@@ -416,13 +410,15 @@ class ObjectCopier(object):
         return True
 
 
+@adapter(IContainer)
+@implementer(IContainerItemRenamer)
 class ContainerItemRenamer(object):
     """An IContainerItemRenamer adapter for containers.
 
     This adapter uses IObjectMover to move an item within the same container
     to a different name. We need to first setup an adapter for IObjectMover:
 
-      >>> from zope.container.interfaces import IContained
+      >>> from zope.location.interfaces import IContained
       >>> gsm = zope.component.getGlobalSiteManager()
       >>> gsm.registerAdapter(ObjectMover, (IContained, ), IObjectMover)
 
@@ -450,7 +446,8 @@ class ContainerItemRenamer(object):
       >>> container['bar'] is foo
       True
 
-    If the item being renamed isn't in the container, a NotFoundError is raised:
+    If the item being renamed isn't in the container, a NotFoundError is
+    raised:
 
       >>> renamer.renameItem('foo', 'bar') # doctest:+ELLIPSIS
       Traceback (most recent call last):
@@ -464,10 +461,6 @@ class ContainerItemRenamer(object):
 
     """
 
-    adapts(IContainer)
-
-    implements(IContainerItemRenamer)
-
     def __init__(self, container):
         self.container = container
 
@@ -486,6 +479,8 @@ class ContainerItemRenamer(object):
         return mover.moveTo(self.container, newName)
 
 
+@adapter(IOrderedContainer)
+@implementer(IContainerItemRenamer)
 class OrderedContainerItemRenamer(ContainerItemRenamer):
     """Renames items within an ordered container.
 
@@ -494,7 +489,7 @@ class OrderedContainerItemRenamer(ContainerItemRenamer):
     To illustrate, we need to setup an IObjectMover, which is used in the
     renaming:
 
-      >>> from zope.container.interfaces import IContained
+      >>> from zope.location.interfaces import IContained
       >>> gsm = zope.component.getGlobalSiteManager()
       >>> gsm.registerAdapter(ObjectMover, (IContained, ), IObjectMover)
 
@@ -547,10 +542,6 @@ class OrderedContainerItemRenamer(ContainerItemRenamer):
 
     """
 
-    adapts(IOrderedContainer)
-
-    implements(IContainerItemRenamer)
-
     def renameItem(self, oldName, newName):
         order = list(self.container.keys())
         newName = self._renameItem(oldName, newName)
@@ -559,6 +550,8 @@ class OrderedContainerItemRenamer(ContainerItemRenamer):
         return newName
 
 
+@adapter(IAnnotations)
+@implementer(IPrincipalClipboard)
 class PrincipalClipboard(object):
     """Principal clipboard
 
@@ -566,10 +559,6 @@ class PrincipalClipboard(object):
     ``{'action':action, 'target':target}``.
     """
 
-    adapts(IAnnotations)
-
-    implements(IPrincipalClipboard)
-
     def __init__(self, annotation):
         self.context = annotation
 
@@ -582,7 +571,7 @@ class PrincipalClipboard(object):
         contents = self.getContents()
         actions = []
         for target in targets:
-            actions.append({'action':action, 'target':target})
+            actions.append({'action': action, 'target': target})
         self.context['clipboard'] = contents + tuple(actions)
 
     def setContents(self, clipboard):
@@ -594,15 +583,14 @@ class PrincipalClipboard(object):
         return self.context.get('clipboard', ())
 
 
+@implementer(INameChooser)
 class ExampleContainer(SampleContainer):
     # Sample container used for examples in doc stringss in this module
 
-    implements(INameChooser)
-
     def chooseName(self, name, ob):
-       while name in self:
-          name += '_'
-       return name
+        while name in self:
+            name += '_'
+        return name
 
 
 def dispatchToSublocations(object, event):
@@ -619,8 +607,8 @@ def dispatchToSublocations(object, event):
       ...     def __repr__(self):
       ...         return '%s(%s)' % (self.__class__.__name__, self.__name__)
 
-      >>> class C(L):
-      ...     implements(ISublocations)
+      >>> @implementer(ISublocations)
+      ... class C(L):
       ...     def __init__(self, name, *subs):
       ...         L.__init__(self, name)
       ...         self.subs = subs
@@ -666,8 +654,7 @@ def dispatchToSublocations(object, event):
 
     we see that our handler has seen all of the subobjects:
 
-      >>> seenreprs = map(repr, seen)
-      >>> seenreprs.sort()
+      >>> seenreprs = sorted(map(repr, seen))
       >>> seenreprs #doctest: +NORMALIZE_WHITESPACE
       ['(C(1), C(1))', '(C(11), C(1))', '(C(12), C(1))',
        '(L(111), C(1))', '(L(112), C(1))', '(L(121), C(1))',
@@ -677,5 +664,4 @@ def dispatchToSublocations(object, event):
     subs = ISublocations(object, None)
     if subs is not None:
         for sub in subs.sublocations():
-            for ignored in zope.component.subscribers((sub, event), None):
-                pass # They do work in the adapter fetch
+            zope.component.handle(sub, event)
