@@ -15,7 +15,8 @@
 """
 __docformat__ = 'restructuredtext'
 
-from zope.interface import Interface, implements
+from zope.interface import Interface, implementer
+
 
 class IObjectMover(Interface):
     """Use `IObjectMover(obj)` to move an object somewhere."""
@@ -36,6 +37,7 @@ class IObjectMover(Interface):
         ``False``.
         """
 
+
 class IObjectCopier(Interface):
 
     def copyTo(target, new_name=None):
@@ -56,6 +58,7 @@ class IObjectCopier(Interface):
         ``False``.
         """
 
+
 class IContainerItemRenamer(Interface):
 
     def renameItem(oldName, newName):
@@ -66,6 +69,7 @@ class IContainerItemRenamer(Interface):
         Raises DuplicationError if newName is already used in the container.
         """
 
+
 class IPrincipalClipboard(Interface):
     """Interface for adapters that store/retrieve clipboard information
     for a principal.
@@ -86,8 +90,11 @@ class IPrincipalClipboard(Interface):
     def getContents():
         """Return the contents of the clipboard"""
 
+
 class IItemNotFoundError(Interface):
     pass
 
+
+@implementer(IItemNotFoundError)
 class ItemNotFoundError(LookupError):
-    implements(IItemNotFoundError)
+    pass
