@@ -13,8 +13,9 @@
 ##############################################################################
 """Object Copier Tests
 """
-import unittest
 import doctest
+import re
+import unittest
 
 import zope.component
 from zope.traversing.api import traverse
@@ -22,12 +23,23 @@ from zope.component.eventtesting import clearEvents
 from zope.component.eventtesting import getEvents
 from zope.copypastemove import ObjectCopier
 from zope.copypastemove.interfaces import IObjectCopier
+from zope.testing import renormalizing
 
 from zope.container import testing
 
+checker = renormalizing.RENormalizing([
+    # Python 3 unicode removed the "u".
+    (re.compile("u('.*?')"),
+     r"\1"),
+    (re.compile('u(".*?")'),
+     r"\1"),
+])
+
+
 class File(object):
     pass
 
+
 def test_copy_events():
     """
     Prepare an IObjectCopier::
@@ -39,7 +51,7 @@ def test_copy_events():
 
       >>> from zope.container.sample import SampleContainer
       >>> root = SampleContainer()
-      
+
     Prepare some objects::
 
       >>> folder = SampleContainer()
@@ -52,7 +64,7 @@ def test_copy_events():
     Now make a copy::
 
       >>> clearEvents()
-      >>> copier = IObjectCopier(foo)  
+      >>> copier = IObjectCopier(foo)
       >>> copier.copyTo(folder, u'bar')
       u'bar'
 
@@ -82,7 +94,7 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         testing.ContainerPlacefulSetup.setUp(self)
         self.buildFolders()
         zope.component.provideAdapter(ObjectCopier, (None,), IObjectCopier)
-        
+
     def test_copytosame(self):
         root = self.rootFolder
         container = traverse(root, 'folder1')
@@ -90,8 +102,8 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         copier = IObjectCopier(file)
         copier.copyTo(container, 'file1')
-        self.failUnless('file1' in container)
-        self.failUnless('file1-2' in container)
+        self.assertTrue('file1' in container)
+        self.assertTrue('file1-2' in container)
 
     def test_copytosamewithnewname(self):
         root = self.rootFolder
@@ -100,8 +112,8 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         copier = IObjectCopier(file)
         copier.copyTo(container, 'file2')
-        self.failUnless('file1' in container)
-        self.failUnless('file2' in container)
+        self.assertTrue('file1' in container)
+        self.assertTrue('file2' in container)
 
     def test_copytoother(self):
         root = self.rootFolder
@@ -111,8 +123,8 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         copier = IObjectCopier(file)
         copier.copyTo(target, 'file1')
-        self.failUnless('file1' in container)
-        self.failUnless('file1' in target)
+        self.assertTrue('file1' in container)
+        self.assertTrue('file1' in target)
 
     def test_copytootherwithnewname(self):
         root = self.rootFolder
@@ -122,8 +134,8 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         copier = IObjectCopier(file)
         copier.copyTo(target, 'file2')
-        self.failUnless('file1' in container)
-        self.failUnless('file2' in target)
+        self.assertTrue('file1' in container)
+        self.assertTrue('file2' in target)
 
     def test_copytootherwithnamecollision(self):
         root = self.rootFolder
@@ -136,10 +148,10 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         copier.copyTo(target, 'file1')
         # we do it twice, just to test auto-name generation
         copier.copyTo(target, 'file1')
-        self.failUnless('file1' in container)
-        self.failUnless('file1' in target)
-        self.failUnless('file1-2' in target)
-        self.failUnless('file1-3' in target)
+        self.assertTrue('file1' in container)
+        self.assertTrue('file1' in target)
+        self.assertTrue('file1-2' in target)
+        self.assertTrue('file1-3' in target)
 
     def test_copyable(self):
         root = self.rootFolder
@@ -147,7 +159,7 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         container['file1'] = File()
         file = traverse(root, 'folder1/file1')
         copier = IObjectCopier(file)
-        self.failUnless(copier.copyable())
+        self.assertTrue(copier.copyable())
 
     def test_copyableTo(self):
         #  A file should be copyable to a folder that has an
@@ -157,15 +169,15 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         container['file1'] = File()
         file = traverse(root, 'folder1/file1')
         copier = IObjectCopier(file)
-        self.failUnless(copier.copyableTo(container, 'file1'))
-        
+        self.assertTrue(copier.copyableTo(container, 'file1'))
+
     def test_copyfoldertosibling(self):
         root = self.rootFolder
         target = traverse(root, '/folder2')
         source = traverse(root, '/folder1/folder1_1')
         copier = IObjectCopier(source)
         copier.copyTo(target)
-        self.failUnless('folder1_1' in target)
+        self.assertTrue('folder1_1' in target)
 
     def test_copyfoldertosame(self):
         root = self.rootFolder
@@ -173,7 +185,7 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1/folder1_1')
         copier = IObjectCopier(source)
         copier.copyTo(target)
-        self.failUnless('folder1_1' in target)
+        self.assertTrue('folder1_1' in target)
 
     def test_copyfoldertosame2(self):
         root = self.rootFolder
@@ -181,7 +193,7 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1/folder1_1/folder1_1_1')
         copier = IObjectCopier(source)
         copier.copyTo(target)
-        self.failUnless('folder1_1_1' in target)
+        self.assertTrue('folder1_1_1' in target)
 
     def test_copyfolderfromroot(self):
         root = self.rootFolder
@@ -189,7 +201,7 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1')
         copier = IObjectCopier(source)
         copier.copyTo(target)
-        self.failUnless('folder1' in target)
+        self.assertTrue('folder1' in target)
 
     def test_copyfolderfromroot2(self):
         root = self.rootFolder
@@ -197,12 +209,14 @@ class ObjectCopierTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1')
         copier = IObjectCopier(source)
         copier.copyTo(target)
-        self.failUnless('folder1' in target)
+        self.assertTrue('folder1' in target)
+
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(ObjectCopierTest),
         doctest.DocTestSuite(
-                    setUp=testing.ContainerPlacefulSetup().setUp,
-                    tearDown=testing.ContainerPlacefulSetup().tearDown),
-        ))
+            setUp=testing.ContainerPlacefulSetup().setUp,
+            tearDown=testing.ContainerPlacefulSetup().tearDown,
+            checker=checker),
+    ))
