@@ -13,8 +13,9 @@
 ##############################################################################
 """Object Mover Tests
 """
-import unittest
 import doctest
+import re
+import unittest
 
 import zope.component
 from zope.traversing.api import traverse
@@ -22,19 +23,30 @@ from zope.component.eventtesting import clearEvents
 from zope.component.eventtesting import getEvents
 from zope.copypastemove import ObjectMover
 from zope.copypastemove.interfaces import IObjectMover
+from zope.testing import renormalizing
 
 from zope.container import testing
 
+checker = renormalizing.RENormalizing([
+    # Python 3 unicode removed the "u".
+    (re.compile("u('.*?')"),
+     r"\1"),
+    (re.compile('u(".*?")'),
+     r"\1"),
+])
+
+
 class File(object):
     pass
 
+
 def test_move_events():
     """
     We need a root folder::
 
       >>> from zope.container.sample import SampleContainer
       >>> root = SampleContainer()
-      
+
     Prepare the setup::
 
       >>> from zope import component
@@ -96,7 +108,7 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         testing.ContainerPlacefulSetup.setUp(self)
         self.buildFolders()
         zope.component.provideAdapter(ObjectMover, (None,), )
- 
+
     def test_movetosame(self):
         # Should be a noop, because "moving" to same location
         root = self.rootFolder
@@ -105,8 +117,8 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
         mover.moveTo(container, 'file1')
-        self.failUnless('file1' in container)
-        self.assertEquals(len(container), 2)
+        self.assertTrue('file1' in container)
+        self.assertEqual(len(container), 2)
 
     def test_movetosamewithnewname(self):
         root = self.rootFolder
@@ -115,8 +127,8 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
         mover.moveTo(container, 'file2')
-        self.failIf('file1' in container)
-        self.failUnless('file2' in container)
+        self.assertFalse('file1' in container)
+        self.assertTrue('file2' in container)
 
     def test_movetoother(self):
         root = self.rootFolder
@@ -126,8 +138,8 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
         mover.moveTo(target, 'file1')
-        self.failIf('file1' in container)
-        self.failUnless('file1' in target)
+        self.assertFalse('file1' in container)
+        self.assertTrue('file1' in target)
 
     def test_movetootherwithnewname(self):
         root = self.rootFolder
@@ -137,8 +149,8 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
         mover.moveTo(target, 'file2')
-        self.failIf('file1' in container)
-        self.failUnless('file2' in target)
+        self.assertFalse('file1' in container)
+        self.assertTrue('file2' in target)
 
     def test_movetootherwithnamecollision(self):
         root = self.rootFolder
@@ -149,9 +161,9 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
         mover.moveTo(target, 'file1')
-        self.failIf('file1' in container)
-        self.failUnless('file1' in target)
-        self.failUnless('file1-2' in target)
+        self.assertFalse('file1' in container)
+        self.assertTrue('file1' in target)
+        self.assertTrue('file1-2' in target)
 
     def test_moveable(self):
         root = self.rootFolder
@@ -159,7 +171,7 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         container['file1'] = File()
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
-        self.failUnless(mover.moveable())
+        self.assertTrue(mover.moveable())
 
     def test_moveableTo(self):
         #  A file should be moveable to a folder that has an
@@ -169,7 +181,7 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         container['file1'] = File()
         file = traverse(root, 'folder1/file1')
         mover = IObjectMover(file)
-        self.failUnless(mover.moveableTo(container, 'file1'))
+        self.assertTrue(mover.moveableTo(container, 'file1'))
 
     def test_movefoldertosibling(self):
         root = self.rootFolder
@@ -177,7 +189,7 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1/folder1_1')
         mover = IObjectMover(source)
         mover.moveTo(target)
-        self.failUnless('folder1_1' in target)
+        self.assertTrue('folder1_1' in target)
 
     def test_movefoldertosame(self):
         # Should be a noop, because "moving" to same location
@@ -186,8 +198,8 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1/folder1_1')
         mover = IObjectMover(source)
         mover.moveTo(target)
-        self.failUnless('folder1_1' in target)
-        self.assertEquals(len(target), 1)
+        self.assertTrue('folder1_1' in target)
+        self.assertEqual(len(target), 1)
 
     def test_movefoldertosame2(self):
         # Should be a noop, because "moving" to same location
@@ -196,8 +208,8 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1/folder1_1/folder1_1_1')
         mover = IObjectMover(source)
         mover.moveTo(target)
-        self.failUnless('folder1_1_1' in target)
-        self.assertEquals(len(target), 1)
+        self.assertTrue('folder1_1_1' in target)
+        self.assertEqual(len(target), 1)
 
     def test_movefolderfromroot(self):
         root = self.rootFolder
@@ -205,7 +217,7 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1')
         mover = IObjectMover(source)
         mover.moveTo(target)
-        self.failUnless('folder1' in target)
+        self.assertTrue('folder1' in target)
 
     def test_movefolderfromroot2(self):
         root = self.rootFolder
@@ -213,13 +225,14 @@ class ObjectMoverTest(testing.ContainerPlacefulSetup, unittest.TestCase):
         source = traverse(root, '/folder1')
         mover = IObjectMover(source)
         mover.moveTo(target)
-        self.failUnless('folder1' in target)
+        self.assertTrue('folder1' in target)
+
 
-        
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(ObjectMoverTest),
         doctest.DocTestSuite(
-                    setUp=testing.ContainerPlacefulSetup().setUp,
-                    tearDown=testing.ContainerPlacefulSetup().tearDown),
-        ))
+            setUp=testing.ContainerPlacefulSetup().setUp,
+            tearDown=testing.ContainerPlacefulSetup().tearDown,
+            checker=checker),
+    ))
